# `Ligare.platform`

Libraries for developing PaaS software.

# `Ligare` Development Dependencies

During development of `Ligare.platform`, you may need to explicitly install other `Ligare` dependencies.

If developing from the root repository, install with:
- `pip install -e src/database`
